# zw_outliersdetec

   This is a small outliers-detection package. You can click
[Github-vidiewei](https://github.com/vidiewei) to see more about this package.

This package includes six algorithms for unsupervised-outliers-detection
1、HOT-SAX  2、PAPR_RW  3、IntervalSets  4、iForest  5、RDOS  6、FastVOA